//
//  Asteroid.m
//  Asteroids
//
//  Created by Nathan Demick on 12/14/10.
//  Copyright 2010 Ganbaru Games. All rights reserved.
//

#import "Asteroid.h"

@implementation Asteroid

// Create setters/getters for these properties
@synthesize size, velocity;

- (id)initWithTexture:(CCTexture2D *)texture rect:(CGRect)rect
{
	if ((self = [super initWithTexture:texture rect:rect]))
	{
		// Make sure to schedule the "update" method to run
		[self scheduleUpdate];
	}
	return self;
}

- (void)update:(ccTime)dt
{
	// Rotate (based on time interval between each frame)
	[self setRotation:self.rotation + (float)dt * 15];
	
	// Move
	[self setPosition:ccp(self.position.x + velocity.x, self.position.y + velocity.y)];
	
	// Get window size
	CGSize windowSize = [CCDirector sharedDirector].winSize;

	// If object moves off the bounds of the screen, make it appear on the other size
	if (self.position.x < 0)
		[self setPosition:ccp(windowSize.width, self.position.y)];
	else if (self.position.x > windowSize.width)
		[self setPosition:ccp(0, self.position.y)];
	
	if (self.position.y < 0)
		[self setPosition:ccp(self.position.x, windowSize.height)];
	else if (self.position.y > windowSize.height)
		[self setPosition:ccp(self.position.x, 0)];
}

// Super-basic AABB collision detection
- (bool)collidesWith:(CCSprite *)obj
{
	// Create two rectangles with CGRectMake, using each sprite's x/y position and width/height
	CGRect ownRect = CGRectMake(self.position.x, self.position.y, self.contentSize.width, self.contentSize.height);
	CGRect otherRect = CGRectMake(obj.position.x, obj.position.y, obj.contentSize.width, obj.contentSize.height);
	
	// Feed the results into CGRectIntersectsRect() which tells if the rectangles intersect (obviously)
	return CGRectIntersectsRect(ownRect, otherRect);
}
@end
